@@ -14,10 +14,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECFLAGS': '-Wno-unused-result -fno-common -dynamic',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/bin',
- 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
+ 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/bin',
+ 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4',
  'BLDLIBRARY': '',
- 'BLDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
+ 'BLDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-apple-darwin15.6.0',
@@ -26,20 +26,25 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CCSHARED': '',
  'CFLAGS': '-Wno-unused-result -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os ',
  'CFLAGSFORSHARED': '',
+ 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-pipe -Os ',
- 'CONFIGURE_CPPFLAGS': '-I/opt/local/include/openssl-1.0 -I/opt/local/include',
- 'CONFIGURE_LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
- 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -Os ' 'LDFLAGS=-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ' 'CPPFLAGS=-I/opt/local/include/openssl-1.0 -I/opt/local/include'",
- 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include',
- 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'CONFIGURE_CPPFLAGS': '-I/opt/local/libexec/openssl11/include -I/opt/local/include',
+ 'CONFIGURE_LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
+ 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' '--with-ensurepip=no' '--with-system-expat' '--with-system-ffi' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -Os ' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -I/opt/local/include'",
+ 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/include',
+ 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/include/python3.4m',
  'COREPYTHONPATH': ':plat-darwin',
- 'CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include',
+ 'COVERAGE_INFO': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python34/python34/work/Python-3.4.10/coverage.info',
+ 'COVERAGE_REPORT': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python34/python34/work/Python-3.4.10/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
+ 'CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/libexec/openssl11/include -I/opt/local/include',
  'CXX': '/usr/bin/clang++',
- 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3 /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3 /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/lib-dynload',
- 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
+ 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4 /opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4 /opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4/lib-dynload',
+ 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/lib-dynload',
+ 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4/lib-dynload',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
@@ -51,10 +56,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
+ 'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
- 'EXTRAPLATDIR': '@EXTRAPLATDIR@',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
@@ -70,12 +75,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 1,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 0,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
@@ -117,7 +122,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 0,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 0,
  'HAVE_EPOLL': 0,
  'HAVE_EPOLL_CREATE1': 0,
  'HAVE_ERF': 1,
@@ -158,8 +165,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
+ 'HAVE_GETENTROPY': 0,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 1,
@@ -188,6 +195,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 0,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
  'HAVE_IF_NAMEINDEX': 1,
@@ -218,6 +226,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
@@ -254,11 +263,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PAUSE': 1,
  'HAVE_PIPE2': 0,
  'HAVE_PLOCK': 0,
- 'HAVE_POLL': 0,
- 'HAVE_POLL_H': 0,
+ 'HAVE_POLL': 1,
+ 'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 0,
  'HAVE_POSIX_FALLOCATE': 0,
  'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
  'HAVE_PTHREAD_ATFORK': 1,
@@ -270,6 +280,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_RAND_EGD': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -280,7 +291,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
- 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
+ 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_ROUND': 1,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
@@ -357,6 +368,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 1,
  'HAVE_SYS_FILE_H': 1,
@@ -369,6 +381,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 0,
@@ -421,6 +434,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WCSCOLL': 1,
  'HAVE_WCSFTIME': 1,
  'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
@@ -429,57 +443,58 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGTAG': '',
  'HGVERSION': '',
  'HOST_GNU_TYPE': 'x86_64-apple-darwin15.6.0',
- 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
- 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include',
- 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
+ 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/include /opt/local/Library/Frameworks/Python.framework/Versions/3.4/include /opt/local/Library/Frameworks/Python.framework/Versions/3.4/include/python3.4m /opt/local/Library/Frameworks/Python.framework/Versions/3.4/include/python3.4m',
+ 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/include',
+ 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/include/python3.4m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'Python.framework/Versions/3.3/Python',
+ 'INSTSONAME': 'Python.framework/Versions/3.4/Python',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': '/usr/bin/clang++ -bundle -undefined dynamic_lookup',
- 'LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
+ 'LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'LDLAST': '',
- 'LDLIBRARY': 'Python.framework/Versions/3.3/Python',
+ 'LDLIBRARY': 'Python.framework/Versions/3.4/Python',
  'LDLIBRARYDIR': '',
- 'LDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
- 'LDVERSION': '3.3m',
+ 'LDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
+ 'LDVERSION': '3.4m',
  'LIBC': '',
- 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
- 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib',
- 'LIBFFI_INCLUDEDIR': '',
+ 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4',
+ 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib',
+ 'LIBFFI_INCLUDEDIR': '/opt/local/include',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/pkgconfig',
- 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/config-3.3m',
- 'LIBRARY': 'libpython3.3m.a',
+ 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/pkgconfig',
+ 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4/config-3.4m',
+ 'LIBRARY': 'libpython3.4m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': ' -ldl  -framework CoreFoundation',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': '/usr/bin/clang',
- 'LINKFORSHARED': '-framework CoreFoundation Python.framework/Versions/3.3/Python',
+ 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4/config-3.4m -lpython3.4m -ldl -framework CoreFoundation',
+ 'LIPO_32BIT_FLAGS': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'darwin',
  'MACHDEPPATH': ':plat-darwin',
- 'MACHDEPS': 'plat-darwin @EXTRAPLATDIR@',
+ 'MACHDEPS': 'plat-darwin',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
+ 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4',
  'MACOSX_DEPLOYMENT_TARGET': '10.11',
  'MAINCC': '/usr/bin/clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/share/man',
+ 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/share/man',
  'MKDIR_P': './install-sh -c -d',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/_operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/atexitmodule.o  Modules/_stat.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/_tracemalloc.o Modules/hashtable.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
@@ -522,20 +537,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os ',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os  -I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include  -DPy_BUILD_CORE',
- 'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os  -Werror=declaration-after-statement -I. -IInclude -I./Include -I/opt/local/libexec/openssl11/include -I/opt/local/include  -DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/libexec/openssl11/include -I/opt/local/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
+ 'PY_LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
+ 'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
- 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib',
+ 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python34/python34/work/Python-3.4.10',
+ 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
@@ -561,12 +578,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
- 'SOABI': 'cpython-33m',
+ 'SOABI': 'cpython-34m',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '',
@@ -576,20 +593,20 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7 ./python',
+ 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python34/python34/work/Python-3.4.10 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7 ./python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python34/python34/work/Python-3.4.10 ./python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_DEPS': '\\ \\',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 1,
- 'VERSION': '3.3',
+ 'VERSION': '3.4',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
@@ -602,9 +619,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
- 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
- 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/share',
- 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3',
- 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3',
+ 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python34/python34/work/Python-3.4.10',
+ 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python34/python34/work/Python-3.4.10',
+ 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4/share',
+ 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4',
+ 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.4',
  'srcdir': '.'}
